'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

require('./wunderbar.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * A react svg component that displays a ruler with major and minor tick marks within a specified range of values. Can show key points of interest as markers and highlight regions of interesting activity on the ruler.
 * @author [Pradeep Roark] (https://github.com/prark/)
 * @example ../examples/example.md
 */
var Wunderbar = function Wunderbar(props) {
    var x = props.x;
    var y = props.y;
    var width = props.width;
    var interval = props.width / (props.max - props.min);
    var ticks = width / interval;
    var height = props.height;
    var majorTicks = width / props.majorTickEvery;
    // const pointer = (currentPoint) =>  [currentPoint * interval,20,currentPoint * interval,0,(currentPoint * interval) + (2 * interval),0];
    var pointer = function pointer(currentPoint, height) {
        var x1 = (currentPoint - props.min) * interval - interval / 2 + props.bevelPadding;
        var y1 = 0;
        var x2 = x1 + interval;
        var y2 = 0;
        var x3 = x1 + interval / 2;
        var y3 = height / 2;
        return [x1, y1, x2, y2, x3, y3];
    };
    var highlightRegion = props.highlightRegion;
    var scaleFill = props.scaleFill;
    var majorTickStroke = props.majorTickStroke;
    var minorTickStroke = props.minorTickStroke;
    var highlightFill = props.highlightFill;
    var pointerStroke = props.pointerStroke;
    var pointsOfInterest = props.pointsOfInterest || [];
    var MTT = [];
    var leftMargin = x + props.bevelPadding;
    for (var i = props.min; i <= props.max; i += props.majorTickEvery) {
        MTT.push(i);
    }
    return _react2.default.createElement(
        'svg',
        { x: x, y: y, height: height + 50, width: width + props.bevelPadding * 2 },
        _react2.default.createElement(
            'g',
            null,
            _react2.default.createElement('rect', { width: width + props.bevelPadding * 2, height: height, fill: scaleFill, rx: 5, ry: 5 }),
            highlightRegion && highlightRegion.length == 2 && _react2.default.createElement('rect', { x: (highlightRegion[0] - props.min) * interval, y: height / 2, width: (highlightRegion[1] - highlightRegion[0]) * interval, height: height / 2, fill: highlightFill, opacity: '0.75' }),
            Array(ticks).fill(0).map(function (r, i) {
                return _react2.default.createElement('line', { key: "LINE" + i, x1: i * interval + props.bevelPadding, y1: height / (i % props.majorTickEvery == 0 ? 2 : 1.5), x2: i * interval + props.bevelPadding, y2: height, stroke: i % props.majorTickEvery == 0 ? majorTickStroke : minorTickStroke, strokeWidth: i % props.majorTickEvery == 0 ? 2 : 1 });
            }),
            _react2.default.createElement('polygon', { points: pointer(props.currentPoint, height), fill: pointerStroke }),
            MTT.map(function (v, x) {
                return _react2.default.createElement(
                    'text',
                    { key: "MT" + x, x: x * props.majorTickEvery * interval + props.bevelPadding - interval * 2, y: height / 1.5, fill: props.tickFill, style: props.textStyle },
                    props.majorTickFormatter(v)
                );
            }),
            pointsOfInterest && pointsOfInterest.map(function (poi) {
                return poi.points.map(function (pt, i) {
                    return _react2.default.createElement('circle', { cx: (pt - props.min) * interval, cy: height / 1.5, r: '2', fill: poi.colour, title: poi.title, key: poi.title + i });
                });
            })
        )
    );
};

Wunderbar.defaultProps = {
    x: 0,
    y: 0,
    width: 600,
    height: 50,
    min: 0,
    max: 100,
    minorTickEvery: 1,
    majorTickEvery: 10,
    currentPoint: 0,
    scaleFill: "#0A0908",
    majorTickStroke: "red",
    minorTickStroke: "white",
    highlightFill: "green",
    pointerStroke: "blue",
    tickFill: "#F2F4F3",
    majorTickFormatter: function majorTickFormatter(v) {
        return v;
    },
    bevelPadding: 10,
    textStyle: {
        fontSize: '12px'
    }
};

Wunderbar.propTypes = {
    x: _propTypes2.default.number,
    y: _propTypes2.default.number,
    width: _propTypes2.default.number,
    height: _propTypes2.default.number,
    min: _propTypes2.default.number,
    max: _propTypes2.default.number,
    majorTickEvery: _propTypes2.default.number,
    minorTickEvery: _propTypes2.default.number,
    /**
     * 
     *
     * Location on scale that the pointer is pointing to
     */
    currentPoint: _propTypes2.default.number,
    majorTickStroke: _propTypes2.default.string,
    minorTickStroke: _propTypes2.default.string,
    highlightFill: _propTypes2.default.string,
    pointerStroke: _propTypes2.default.string,
    tickFill: _propTypes2.default.string,
    scaleFill: _propTypes2.default.string,
    bevelPadding: _propTypes2.default.number,
    majorTickFormatter: _propTypes2.default.func,
    textStyle: _propTypes2.default.object
};

exports.default = Wunderbar;